# vim: sw=4:ts=4:et

%define current_version 1.21.2+k3s1.vz8.2

%define install_path  /usr/bin
%define util_path     %{_datadir}/k3s

Name:    k3s
Version: %{current_version}
Release:        1%{?dist}
Summary: Lightweight Kubernetes

Group:   System Environment/Base
License: ASL 2.0
URL:     http://k3s.io
# Build from Source100 by build_k3s.sh
Source0:	k3s-binary-%{version}
Source1:	k3s-server.service
Source2:	k3s-agent.service
# default env
Source3:	k3s-agent-defaults.env
Source4:	k3s-server-defaults.env
# custom env
Source5:	k3s-agent.env
Source6:	k3s-server.env
# firewalld
Source7:	k3s-agent.xml
Source8:	k3s-server.xml
Source9: k3s-server-ha.xml
# keepalived
Source10: k3s_keepalived.conf.sample
Source11: check_apiserver.sh.sample
# log
Source12: k3s-log.conf
Source13: k3s-logrotate.conf

Source100:	https://github.com/k3s-io/k3s/archive/%{name}-%{version}.tar.bz2

ExclusiveArch:	x86_64

Requires: keepalived

%description
The certified Kubernetes distribution built for IoT & Edge computing.

%install
mkdir -p %{buildroot}/%{_bindir}/
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}
mkdir -p %{buildroot}/%{_unitdir}
mkdir -p %{buildroot}/%{_sysconfdir}/firewalld/services/
mkdir -p %{buildroot}/%{_datadir}/%{name}/
mkdir -p %{buildroot}/%{_sysconfdir}/rsyslog.d
mkdir -p %{buildroot}/%{_sysconfdir}/logrotate.d

install -m0755 %{SOURCE0} %{buildroot}/%{_bindir}/k3s
install -m0644 %{SOURCE1} %{SOURCE2} %{buildroot}/%{_unitdir}
install -m0644 %{SOURCE3} %{SOURCE4} %{buildroot}/%{_sysconfdir}/%{name}/
install -m0600 %{SOURCE5} %{SOURCE6} %{buildroot}/%{_sysconfdir}/%{name}/
install -m0644 %{SOURCE7} %{SOURCE8} %{SOURCE9} %{buildroot}/%{_sysconfdir}/firewalld/services/
install -m0600 %{SOURCE10} %{buildroot}/%{_datadir}/%{name}/
install -m0755 %{SOURCE11} %{buildroot}/%{_datadir}/%{name}/
install -m0644 %{SOURCE12} %{buildroot}/%{_sysconfdir}/rsyslog.d/k3s.conf
install -m0644 %{SOURCE13} %{buildroot}/%{_sysconfdir}/logrotate.d/k3s

%post
%systemd_post k3s-server.service
%systemd_post k3s-agent.service
%{_bindir}/systemctl try-restart rsyslog.service

if [ ! -f %{_bindir}/kubectl ]; then
   ln -s %{_bindir}/k3s %{_bindir}/kubectl
fi

%preun
%systemd_preun k3s-server.service
%systemd_preun k3s-agent.service

%postun
%systemd_postun k3s-server.service
%systemd_postun k3s-agent.service

# delete the kubectl symlink only on package removal, not update
if [ $1 -eq 0 ]; then
    if [ -L %{_bindir}/kubectl ]; then
        %{_bindir}/unlink %{_bindir}/kubectl
    fi
fi

%files
%{_bindir}/k3s
%{_sysconfdir}/%{name}/%{name}-agent-defaults.env
%{_sysconfdir}/%{name}/%{name}-server-defaults.env
%{_unitdir}/%{name}-server.service
%{_unitdir}/%{name}-agent.service
%{_sysconfdir}/firewalld/services/%{name}-agent.xml
%{_sysconfdir}/firewalld/services/%{name}-server.xml
%{_sysconfdir}/firewalld/services/%{name}-server-ha.xml
%{_datadir}/%{name}/%{name}_keepalived.conf.sample
%{_datadir}/%{name}/check_apiserver.sh.sample

%config %{_sysconfdir}/%{name}/%{name}-agent.env
%config %{_sysconfdir}/%{name}/%{name}-server.env
%config %{_sysconfdir}/rsyslog.d/k3s.conf
%config %{_sysconfdir}/logrotate.d/k3s

%changelog
* Wed Jun 23 2021 Pavel Vorontsov <pavel.vorontsov@virtuozzo.com> 1.21.2+k3s1.vz8.2
 - Fix k3s binary version (Denis Silakov <dsilakov@virtuozzo.com>)
 - change branch for jenkins
 - use default containerd as container runtime

* Wed Jun 23 2021 Pavel Vorontsov <pavel.vorontsov@virtuozzo.com> 1.21.2+k3s1.vz8.1
 - Add Makefile.version for vzbuild
 - change branch for jenkins
 - use default containerd as container runtime

* Fri Feb 05 2021 VZ Auto Builder <builder@virtuozzo.com> v1.19.5+k3s2.12
 - PSBM-124746 (Pavel Vorontsov <pavel.vorontsov@virtuozzo.com>) (#PSBM-124746)

* Tue Jan 26 2021 Updates Tracker <dsilakov@virtuozzo.com> v1.19.5+k3s2.8
 - try to install the package from the mirror if the main repository is not
available (Pavel Vorontsov <pavel.vorontsov@virtuozzo.com>)
 - Revert "Fix remove tmp directory" (Pavel Vorontsov
<pavel.vorontsov@virtuozzo.com>)
 - Fix source names
 - Fix version processing
 - Fix version processing
 - added execution rights for the file check_apiserver.sh.sample (Pavel
Vorontsov <pavel.vorontsov@virtuozzo.com>)
 - Adjust configs for a more standard way (Denis Silakov
<dsilakov@virtuozzo.com>)
 - changelog is a must for vzbuild (Denis Silakov <dsilakov@virtuozzo.com>)

* Tue Jan 26 2021 Updates Tracker <dsilakov@virtuozzo.com> v1.19.5+k3s2.7
 - try to install the package from the mirror if the main repository is not
available (Pavel Vorontsov <pavel.vorontsov@virtuozzo.com>)
 - Revert "Fix remove tmp directory" (Pavel Vorontsov
<pavel.vorontsov@virtuozzo.com>)
 - Fix version processing
 - Fix version processing
 - added execution rights for the file check_apiserver.sh.sample (Pavel
Vorontsov <pavel.vorontsov@virtuozzo.com>)
 - Adjust configs for a more standard way (Denis Silakov
<dsilakov@virtuozzo.com>)
 - changelog is a must for vzbuild (Denis Silakov <dsilakov@virtuozzo.com>)

* Tue Jan 26 2021 Updates Tracker <dsilakov@virtuozzo.com> v1.19.5+k3s2.6
 - try to install the package from the mirror if the main repository is not
available (Pavel Vorontsov <pavel.vorontsov@virtuozzo.com>)
 - Revert "Fix remove tmp directory" (Pavel Vorontsov
<pavel.vorontsov@virtuozzo.com>)
 - Adjust configs for a more standard way (Denis Silakov
<dsilakov@virtuozzo.com>)
 - changelog is a must for vzbuild (Denis Silakov <dsilakov@virtuozzo.com>)

* Tue Jan 26 2021 Updates Tracker <dsilakov@virtuozzo.com> 1.19.5+k3s2.2
 - fix cgroup2 support (Akihiro Suda <akihiro.suda.cz@hco.ntt.co.jp>)
 - Update k3s-root to v0.7.3 (Brad Davidson <brad.davidson@rancher.com>)
 - Adjust configs for a more standard way (Denis Silakov
<dsilakov@virtuozzo.com>)
 - changelog is a must for vzbuild (Denis Silakov <dsilakov@virtuozzo.com>)

